.. i/o

File I/O
========

The :ref:`read <read>` function works for both EMD 1.0 and older EMD 0.1 files. It reads whole files, single nodes, or selected subsets of data.
The :ref:`save <save>` function writes new files or appends to existing ones. Appending includes diffmerge-like behavior with options to skip or overwrite conflicting data nodes.  More information follows.

.. _read:

****
Read
****

.. autofunction:: emdfile.read


.. _save:

****
Save
****

.. autofunction:: emdfile.save


